@@ -5,6 +5,7 @@ from django import template
 from django.conf import settings
 from django.core.urlresolvers import resolve, Resolver404
 from django.db.models.fields import FieldDoesNotExist
+from django.template.defaultfilters import truncatewords_html
 
 from django_libs import utils
 
@@ -12,6 +13,41 @@ from django_libs import utils
 register = template.Library()
 
 
+@register.tag('block_truncatewords_html')
+def block_truncatewords_html(parser, token):
+    """
+    Allows to truncate any block of content.
+
+    This is useful when rendering other tags that generate content,
+    such as django-cms' ``render_placeholder`` tag, which is not available
+    as an assignment tag::
+
+        {% load libs_tags %}
+        {% block_truncatewords_html 15 %}
+            {% render_placeholder object.placeholder %}
+        {% endblocktruncatewordshtml %}
+
+    """
+    bits = token.contents.split()
+    try:
+        word_count = bits[1]
+    except IndexError:
+        word_count = 15
+    nodelist = parser.parse(('endblocktruncatewordshtml',))
+    parser.delete_first_token()
+    return BlockTruncateWordsHtmlNode(nodelist, word_count)
+
+
+class BlockTruncateWordsHtmlNode(template.Node):
+    def __init__(self, nodelist, word_count):
+        self.nodelist = nodelist
+        self.word_count = word_count
+
+    def render(self, context):
+        output = self.nodelist.render(context)
+        return truncatewords_html(output, self.word_count)
+
+
 @register.assignment_tag
 def calculate_dimensions(image, long_side, short_side):
     """Returns the thumbnail dimensions depending on the images format."""
@@ -67,6 +103,35 @@ def get_profile_for(user):
     return utils.get_profile(user)
 
 
+@register.assignment_tag
+def get_query_params(request, param_name, param_value):
+    """
+    Allows to change one of the URL get parameter while keeping all the others.
+
+    Usage::
+
+        {% load libs_tags %}
+        {% get_query_params request "page" page_obj.next_page_number as query %}
+        <a href="?{{ query }}">Next</a>
+
+    You often need this when you have a paginated set of objects with filters.
+
+    Your url would look something like ``/?region=1&gender=m``. Your paginator
+    needs to create links with ``&page=2`` in them but you must keep the
+    filter values when switching pages.
+
+    :param request: The request instance.
+    :param param_name: The name of the parameter that should be added or
+      updated.
+    :param param_value: The value of the parameter that should be added or
+      updated.
+
+    """
+    query = request.GET.copy()
+    query[param_name] = param_value
+    return query.urlencode()
+
+
 class LoadContextNode(template.Node):
     def __init__(self, fqn):
         self.fqn = fqn
